@@ -23,8 +23,10 @@ if conda_interface_type == 'conda':
     from conda.exports import default_prefix
     from conda.exports import linked_data
     from conda.exports import download as _download
+    from conda.exports import MatchSpec
 
     from conda.models.channel import prioritize_channels
+    from conda.models.dist import Dist
 
     def fetch_index(channel_urls):
         return _fetch_index(prioritize_channels(channel_urls))
@@ -63,3 +65,5 @@ fetch_index, fetch_pkg = fetch_index, fetch_pkg
 Resolve, NoPackagesFound = Resolve, NoPackagesFound
 default_prefix = default_prefix
 linked_data = linked_data
+MatchSpec = MatchSpec
+Dist = Dist
