@@ -1,4 +1,4 @@
-# (c) 2016 Continuum Analytics, Inc. / http://continuum.io
+# (c) 2016 Anaconda, Inc. / https://anaconda.com
 # All Rights Reserved
 #
 # constructor is distributed under the terms of the BSD 3-clause license.
@@ -15,7 +15,8 @@ import re
 import sys
 import tarfile
 
-from .conda_interface import NoPackagesFound, Resolve, fetch_index, fetch_pkg
+from .conda_interface import (NoPackagesFound, Resolve, fetch_index, fetch_pkg,
+                              MatchSpec)
 from .install import name_dist
 from .utils import filename_dist, md5_file
 
@@ -30,7 +31,7 @@ def resolve(info, verbose=False):
         sys.exit("Error: index is empty, maybe 'channels' are missing?")
     specs = info['specs']
     r = Resolve(index)
-    if not any(s.split()[0] == 'python' for s in specs):
+    if not any(MatchSpec(s).name == 'python' for s in specs):
         specs.append('python')
     if verbose:
         print("specs: %r" % specs)
@@ -96,21 +97,6 @@ def parse_packages(lines):
         yield m.group('url'), fn, m.group('md5')
 
 
-def handle_packages(info):
-    for url, fn, md5 in parse_packages(info['packages']):
-        if fn.count('-') < 2:
-            sys.exit("Error: Not a valid conda package filename: '%s'" % fn)
-        dists.append(fn)
-        md5s[fn] = md5
-        if url:
-            urls[fn] = url
-        else:
-            try:
-                urls[fn] = index[fn]['channel']
-            except KeyError:
-                sys.exit("Error: did not find '%s' in any channels" % fn)
-
-
 def move_python_first():
     for dist in list(dists):
         if name_dist(dist) == 'python':
@@ -258,8 +244,6 @@ def main(info, verbose=True, dry_run=False):
     if 'specs' in info:
         resolve(info, verbose)
     exclude_packages(info)
-    if 'packages' in info:
-        handle_packages(info)
 
     if not info.get('install_in_dependency_order'):
         dists.sort()
